# Langgraph-reflection-agent
A simple demonstration of langgraph's AI Agent framework to perform a reflection task and summarise findings

> [!IMPORTANT]  
> You will need to create a .env file and populate it with the following environment variables:
- OPENAI_API_KEY